
################################################################
# This is a generated script based on design: aurora_2lane
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

namespace eval _tcl {
proc get_script_folder {} {
   set script_path [file normalize [info script]]
   set script_folder [file dirname $script_path]
   return $script_folder
}
}
variable script_folder
set script_folder [_tcl::get_script_folder]

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2016.3
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   catch {common::send_msg_id "BD_TCL-109" "ERROR" "This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."}

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source aurora_2lane_script.tcl

# If there is no project opened, this script will create a
# project, but make sure you do not have an existing project
# <./myproj/project_1.xpr> in the current working folder.

set list_projs [get_projects -quiet]
if { $list_projs eq "" } {
   create_project project_1 myproj -part xczu9eg-ffvb1156-1-i-es1
   set_property BOARD_PART xilinx.com:zcu102:part0:1.2 [current_project]
}


# CHANGE DESIGN NAME HERE
set design_name aurora_2lane

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      common::send_msg_id "BD_TCL-001" "INFO" "Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   common::send_msg_id "BD_TCL-002" "INFO" "Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   common::send_msg_id "BD_TCL-003" "INFO" "Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   common::send_msg_id "BD_TCL-004" "INFO" "Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

common::send_msg_id "BD_TCL-005" "INFO" "Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   catch {common::send_msg_id "BD_TCL-114" "ERROR" $errMsg}
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################



# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  variable script_folder

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports

  # Create ports
  set gt_refclk1_n [ create_bd_port -dir I gt_refclk1_n ]
  set gt_refclk1_out [ create_bd_port -dir O -type clk gt_refclk1_out ]
  set gt_refclk1_p [ create_bd_port -dir I gt_refclk1_p ]
  set gt_reset [ create_bd_port -dir I -type rst gt_reset ]
  set_property -dict [ list \
CONFIG.POLARITY {ACTIVE_HIGH} \
 ] $gt_reset
  set gt_reset_out [ create_bd_port -dir O -type rst gt_reset_out ]
  set init_clk_in [ create_bd_port -dir I -type clk init_clk_in ]
  set loopback [ create_bd_port -dir I -from 2 -to 0 loopback ]
  set m_axis_aresetn [ create_bd_port -dir I -type rst m_axis_aresetn ]
  set pll_not_locked_out [ create_bd_port -dir O pll_not_locked_out ]
  set power_down [ create_bd_port -dir I power_down ]
  set s_axis_aclk [ create_bd_port -dir I -type clk s_axis_aclk ]
  set s_axis_aresetn [ create_bd_port -dir I -type rst s_axis_aresetn ]
  set s_axis_tdata [ create_bd_port -dir I -from 63 -to 0 s_axis_tdata ]
  set s_axis_tkeep [ create_bd_port -dir I -from 7 -to 0 s_axis_tkeep ]
  set s_axis_tlast [ create_bd_port -dir I s_axis_tlast ]
  set s_axis_tready [ create_bd_port -dir O s_axis_tready ]
  set s_axis_tvalid [ create_bd_port -dir I s_axis_tvalid ]
  set sync_clk_out [ create_bd_port -dir O -type clk sync_clk_out ]
  set sys_reset_out [ create_bd_port -dir O -type rst sys_reset_out ]
  set tx_channel_up [ create_bd_port -dir O tx_channel_up ]
  set tx_hard_err [ create_bd_port -dir O tx_hard_err ]
  set tx_lane_up [ create_bd_port -dir O -from 0 -to 1 tx_lane_up ]
  set tx_lock [ create_bd_port -dir O tx_lock ]
  set tx_resetdone_out [ create_bd_port -dir O tx_resetdone_out ]
  set tx_system_reset [ create_bd_port -dir I -type rst tx_system_reset ]
  set_property -dict [ list \
CONFIG.POLARITY {ACTIVE_HIGH} \
 ] $tx_system_reset
  set txn [ create_bd_port -dir O -from 0 -to 1 txn ]
  set txp [ create_bd_port -dir O -from 0 -to 1 txp ]
  set user_clk_out [ create_bd_port -dir O -type clk user_clk_out ]

  # Create instance: aurora, and set properties
  set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b:11.0 aurora ]
  set_property -dict [ list \
CONFIG.Backchannel_mode {Timer} \
CONFIG.CHANNEL_ENABLE {X0Y12 X0Y13} \
CONFIG.C_AURORA_LANES {2} \
CONFIG.C_DRP_IF {false} \
CONFIG.C_GT_LOC_2 {2} \
CONFIG.C_GT_LOC_3 {X} \
CONFIG.C_GT_LOC_4 {X} \
CONFIG.C_INIT_CLK {74.25} \
CONFIG.C_LANE_WIDTH {4} \
CONFIG.C_LINE_RATE {6.25} \
CONFIG.C_REFCLK_FREQUENCY {156.25} \
CONFIG.C_REFCLK_SOURCE {MGTREFCLK1 of Quad X0Y3} \
CONFIG.C_START_LANE {X0Y12} \
CONFIG.C_START_QUAD {Quad_X0Y3} \
CONFIG.C_UCOLUMN_USED {left} \
CONFIG.C_USE_BYTESWAP {true} \
CONFIG.C_active_transceiverquads {1} \
CONFIG.Dataflow_Config {TX-only_Simplex} \
CONFIG.Interface_Mode {Framing} \
CONFIG.SupportLevel {1} \
 ] $aurora

  # Create instance: fifo, and set properties
  set fifo [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_data_fifo:1.1 fifo ]
  set_property -dict [ list \
CONFIG.FIFO_DEPTH {32} \
CONFIG.HAS_TKEEP {1} \
CONFIG.HAS_TLAST {1} \
CONFIG.HAS_TSTRB {0} \
CONFIG.IS_ACLK_ASYNC {1} \
CONFIG.TDATA_NUM_BYTES {8} \
CONFIG.TDEST_WIDTH {0} \
CONFIG.TID_WIDTH {0} \
CONFIG.TUSER_WIDTH {0} \
 ] $fifo

  # Create interface connections
  connect_bd_intf_net -intf_net axis_data_fifo_0_M_AXIS [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins fifo/M_AXIS]

  # Create port connections
  connect_bd_net -net aurora_8b10b_0_gt_refclk1_out [get_bd_ports gt_refclk1_out] [get_bd_pins aurora/gt_refclk1_out]
  connect_bd_net -net aurora_8b10b_0_gt_reset_out [get_bd_ports gt_reset_out] [get_bd_pins aurora/gt_reset_out]
  connect_bd_net -net aurora_8b10b_0_pll_not_locked_out [get_bd_ports pll_not_locked_out] [get_bd_pins aurora/pll_not_locked_out]
  connect_bd_net -net aurora_8b10b_0_sync_clk_out [get_bd_ports sync_clk_out] [get_bd_pins aurora/sync_clk_out]
  connect_bd_net -net aurora_8b10b_0_sys_reset_out [get_bd_ports sys_reset_out] [get_bd_pins aurora/sys_reset_out]
  connect_bd_net -net aurora_8b10b_0_tx_channel_up [get_bd_ports tx_channel_up] [get_bd_pins aurora/tx_channel_up]
  connect_bd_net -net aurora_8b10b_0_tx_hard_err [get_bd_ports tx_hard_err] [get_bd_pins aurora/tx_hard_err]
  connect_bd_net -net aurora_8b10b_0_tx_lane_up [get_bd_ports tx_lane_up] [get_bd_pins aurora/tx_lane_up]
  connect_bd_net -net aurora_8b10b_0_tx_lock [get_bd_ports tx_lock] [get_bd_pins aurora/tx_lock]
  connect_bd_net -net aurora_8b10b_0_tx_resetdone_out [get_bd_ports tx_resetdone_out] [get_bd_pins aurora/tx_resetdone_out]
  connect_bd_net -net aurora_8b10b_0_txn [get_bd_ports txn] [get_bd_pins aurora/txn]
  connect_bd_net -net aurora_8b10b_0_txp [get_bd_ports txp] [get_bd_pins aurora/txp]
  connect_bd_net -net aurora_8b10b_0_user_clk_out [get_bd_ports user_clk_out] [get_bd_pins aurora/user_clk_out] [get_bd_pins fifo/m_axis_aclk]
  connect_bd_net -net axis_data_fifo_0_s_axis_tready [get_bd_ports s_axis_tready] [get_bd_pins fifo/s_axis_tready]
  connect_bd_net -net gt_refclk1_n_1 [get_bd_ports gt_refclk1_n] [get_bd_pins aurora/gt_refclk1_n]
  connect_bd_net -net gt_refclk1_p_1 [get_bd_ports gt_refclk1_p] [get_bd_pins aurora/gt_refclk1_p]
  connect_bd_net -net gt_reset_1 [get_bd_ports gt_reset] [get_bd_pins aurora/gt_reset]
  connect_bd_net -net init_clk_in_1 [get_bd_ports init_clk_in] [get_bd_pins aurora/init_clk_in]
  connect_bd_net -net loopback_1 [get_bd_ports loopback] [get_bd_pins aurora/loopback]
  connect_bd_net -net m_axis_aresetn_1 [get_bd_ports m_axis_aresetn] [get_bd_pins fifo/m_axis_aresetn]
  connect_bd_net -net power_down_1 [get_bd_ports power_down] [get_bd_pins aurora/power_down]
  connect_bd_net -net s_axis_aclk_1 [get_bd_ports s_axis_aclk] [get_bd_pins fifo/s_axis_aclk]
  connect_bd_net -net s_axis_aresetn_1 [get_bd_ports s_axis_aresetn] [get_bd_pins fifo/s_axis_aresetn]
  connect_bd_net -net s_axis_tdata_1 [get_bd_ports s_axis_tdata] [get_bd_pins fifo/s_axis_tdata]
  connect_bd_net -net s_axis_tkeep_1 [get_bd_ports s_axis_tkeep] [get_bd_pins fifo/s_axis_tkeep]
  connect_bd_net -net s_axis_tlast_1 [get_bd_ports s_axis_tlast] [get_bd_pins fifo/s_axis_tlast]
  connect_bd_net -net s_axis_tvalid_1 [get_bd_ports s_axis_tvalid] [get_bd_pins fifo/s_axis_tvalid]
  connect_bd_net -net tx_system_reset_1 [get_bd_ports tx_system_reset] [get_bd_pins aurora/tx_system_reset]

  # Create address segments

  # Perform GUI Layout
  regenerate_bd_layout -layout_string {
   guistr: "# # String gsaved with Nlview 6.6.5b  2016-09-06 bk=1.3687 VDI=39 GEI=35 GUI=JA:1.6
#  -string -flagsOSRD
preplace port tx_channel_up -pg 1 -y 220 -defaultsOSRD
preplace port sync_clk_out -pg 1 -y 420 -defaultsOSRD
preplace port user_clk_out -pg 1 -y 380 -defaultsOSRD
preplace port tx_system_reset -pg 1 -y 370 -defaultsOSRD
preplace port init_clk_in -pg 1 -y 410 -defaultsOSRD
preplace port gt_reset -pg 1 -y 390 -defaultsOSRD
preplace port gt_refclk1_n -pg 1 -y 290 -defaultsOSRD
preplace port tx_resetdone_out -pg 1 -y 300 -defaultsOSRD
preplace port s_axis_tready -pg 1 -y 20 -defaultsOSRD
preplace port power_down -pg 1 -y 350 -defaultsOSRD
preplace port gt_refclk1_out -pg 1 -y 460 -defaultsOSRD
preplace port s_axis_aresetn -pg 1 -y 190 -defaultsOSRD
preplace port s_axis_aclk -pg 1 -y 230 -defaultsOSRD
preplace port gt_refclk1_p -pg 1 -y 310 -defaultsOSRD
preplace port tx_lock -pg 1 -y 280 -defaultsOSRD
preplace port sys_reset_out -pg 1 -y 400 -defaultsOSRD
preplace port m_axis_aresetn -pg 1 -y 210 -defaultsOSRD
preplace port tx_hard_err -pg 1 -y 240 -defaultsOSRD
preplace port gt_reset_out -pg 1 -y 440 -defaultsOSRD
preplace port s_axis_tvalid -pg 1 -y 90 -defaultsOSRD
preplace port s_axis_tlast -pg 1 -y 170 -defaultsOSRD
preplace port pll_not_locked_out -pg 1 -y 200 -defaultsOSRD
preplace portBus tx_lane_up -pg 1 -y 260 -defaultsOSRD
preplace portBus s_axis_tkeep -pg 1 -y 150 -defaultsOSRD
preplace portBus txn -pg 1 -y 340 -defaultsOSRD
preplace portBus txp -pg 1 -y 360 -defaultsOSRD
preplace portBus loopback -pg 1 -y 330 -defaultsOSRD
preplace portBus s_axis_tdata -pg 1 -y 130 -defaultsOSRD
preplace inst fifo -pg 1 -lvl 1 -y 160 -defaultsOSRD
preplace inst aurora -pg 1 -lvl 2 -y 320 -defaultsOSRD
preplace netloc s_axis_tlast_1 1 0 1 NJ
preplace netloc s_axis_tdata_1 1 0 1 NJ
preplace netloc gt_reset_1 1 0 2 NJ 390 NJ
preplace netloc init_clk_in_1 1 0 2 NJ 410 NJ
preplace netloc s_axis_aclk_1 1 0 1 NJ
preplace netloc axis_data_fifo_0_s_axis_tready 1 0 3 30 20 NJ 20 NJ
preplace netloc aurora_8b10b_0_tx_lock 1 2 1 NJ
preplace netloc aurora_8b10b_0_tx_channel_up 1 2 1 NJ
preplace netloc aurora_8b10b_0_gt_reset_out 1 2 1 NJ
preplace netloc s_axis_tkeep_1 1 0 1 NJ
preplace netloc m_axis_aresetn_1 1 0 1 NJ
preplace netloc loopback_1 1 0 2 NJ 330 NJ
preplace netloc aurora_8b10b_0_txn 1 2 1 NJ
preplace netloc aurora_8b10b_0_gt_refclk1_out 1 2 1 NJ
preplace netloc aurora_8b10b_0_tx_lane_up 1 2 1 NJ
preplace netloc aurora_8b10b_0_sys_reset_out 1 2 1 NJ
preplace netloc aurora_8b10b_0_pll_not_locked_out 1 2 1 NJ
preplace netloc tx_system_reset_1 1 0 2 NJ 370 NJ
preplace netloc gt_refclk1_n_1 1 0 2 20J 300 370J
preplace netloc aurora_8b10b_0_txp 1 2 1 NJ
preplace netloc axis_data_fifo_0_M_AXIS 1 1 1 370
preplace netloc power_down_1 1 0 2 NJ 350 NJ
preplace netloc aurora_8b10b_0_tx_hard_err 1 2 1 NJ
preplace netloc s_axis_tvalid_1 1 0 1 NJ
preplace netloc s_axis_aresetn_1 1 0 1 NJ
preplace netloc gt_refclk1_p_1 1 0 2 NJ 310 380J
preplace netloc aurora_8b10b_0_user_clk_out 1 0 3 30 510 NJ 510 720
preplace netloc aurora_8b10b_0_tx_resetdone_out 1 2 1 NJ
preplace netloc aurora_8b10b_0_sync_clk_out 1 2 1 NJ
levelinfo -pg 1 0 200 550 740 -top 0 -bot 520
",
}

  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


