library IEEE;
use IEEE.std_logic_1164.all;

library UNISIM;
use UNISIM.Vcomponents.all;

entity top_hsstp_1lane_10000mbps is
	port (
		oLEDs:                   out std_logic_vector(7 downto 0);
		iDIPs:                   in  std_logic_vector(7 downto 0);
		iClk125P:                in  std_logic;
		iClk125N:                in  std_logic;
		iClk74_25P:              in  std_logic;
		iClk74_25N:              in  std_logic;
		iAuroraHpc1RefAnalyzerN: in  std_logic;
		iAuroraHpc1RefAnalyzerP: in  std_logic;
		oAuroraHpc1TxN:          out std_logic_vector(0 to 0);
		oAuroraHpc1TxP:          out std_logic_vector(0 to 0)
	);
end entity;

architecture behavioral of top_hsstp_1lane_10000mbps is
	signal wTraceClkSdr:  std_logic;
	signal wTraceDataSdr: std_logic_vector(31 downto 0);

	signal wClk125:       std_logic;
	signal wClk74_25:     std_logic;
	signal wUserClk:      std_logic;
	signal wAuroraRef:    std_logic;

	signal wTraceRst:     std_logic;
	signal wUserRst:      std_logic;

	signal wFifoReady:    std_logic;
	signal wFifoValid:    std_logic;

	signal wTxData:       std_logic_vector(31 downto 0);
	signal wTxDataK:      std_logic_vector( 3 downto 0);

begin
	-- main block design containing the Zynq UltraScale+ MPSoC
	yDesign: entity work.mpsoc port map (
		TRACE_CLK_SDR   => wTraceClkSdr,
		TRACE_DATA      => wTraceDataSdr
	);

	yAdapter: entity work.serial_trace_adapter_gt port map (
		iTraceClk       => wTraceClkSdr,
		iTraceRst       => wTraceRst,
		iUserClk        => wUserClk,
		iUserRst        => wUserRst,
		iData           => wTraceDataSdr,
		oFifoReady      => wFifoReady,
		oFifoValid      => wFifoValid,
		oData           => wTxData,
		oDataK          => wTxDataK
	);

	yGt: entity work.gt_1lane port map (
		gtwiz_reset_clk_freerun_in(0)        => wClk74_25,
		gtwiz_reset_all_in(0)                => wUserRst,
		gtrefclk00_in(0)                     => wAuroraRef,

		gtwiz_userclk_tx_reset_in            => (others => '0'),
		gtwiz_userclk_tx_usrclk2_out(0)      => wUserClk,
		gtwiz_reset_tx_pll_and_datapath_in   => (others => '0'),
		gtwiz_reset_tx_datapath_in           => (others => '0'),
		gtwiz_userdata_tx_in                 => wTxData,
		tx8b10ben_in                         => (others => '1'),
		txctrl0_in                           => (others => '0'), -- ignored in 8b10b mode
		txctrl1_in                           => (others => '0'), -- ignored in 8b10b mode
		txctrl2_in(7 downto 4)               => (others => '0'), -- upper bits are ignored
		txctrl2_in(3 downto 0)               => wTxDataK,
		gthtxn_out                           => oAuroraHpc1TxN,
		gthtxp_out                           => oAuroraHpc1TxP,

		gtwiz_userclk_rx_reset_in            => (others => '0'),
		--gtwiz_buffbypass_rx_reset_in         => (others => '0'),
		--gtwiz_buffbypass_rx_start_user_in    => (others => '0'),
		gtwiz_reset_rx_pll_and_datapath_in   => (others => '0'),
		gtwiz_reset_rx_datapath_in           => (others => '0'),
		gthrxn_in                            => (others => '0'),
		gthrxp_in                            => (others => '0'),
		rx8b10ben_in                         => (others => '0'),
		rxbufreset_in                        => (others => '0'),
		rxcommadeten_in                      => (others => '0'),
		rxmcommaalignen_in                   => (others => '0'),
		rxpcommaalignen_in                   => (others => '0')
	);

	yBufAurora: IBUFDS_GTE4 port map (
		O         => wAuroraRef,
		I         => iAuroraHpc1RefAnalyzerP,
		IB        => iAuroraHpc1RefAnalyzerN,
		CEB       => '0',
		ODIV2     => open
	);

	yBuf125: IBUFGDS port map (
		O               => wClk125,
		I               => iClk125P,
		IB              => iClk125N
	);

	yBuf74_25:        IBUFGDS port map (
		O               => wClk74_25,
		I               => iClk74_25P,
		IB              => iClk74_25N
	);

	-- this module is only used for debugging purposes to verify that all clocks are running and to see whether trace data is currently being transmitted
	yLedCommon: entity work.led_common generic map (
		gTraceSdrFreq   => 250.00e6,
		gUserFreq       => 250.00e6
	) port map (
		iClk125         => wClk125,
		iClk74_25       => wClk74_25,
		iClkTraceSdr    => wTraceClkSdr,
		iClkUser        => wUserClk,
		iTraceDataSdr   => wTraceDataSdr,
		iFifoReady      => wFifoReady,
		iFifoValid      => wFifoValid,
		oBlink125       => oLEDs(0),
		oBlink74_25     => oLEDs(1),
		oBlinkTraceSdr  => oLEDs(2),
		oBlinkUser      => oLEDs(3),
		oTraceActive    => oLEDs(4),
		oFifoOverflow   => oLEDs(5)
	);

	oLEDs(6) <= iDIPs(6);
	oLEDs(7) <= iDIPs(7);

	wTraceRst  <=     iDIPs(6);
	wUserRst   <=     iDIPs(7);
end architecture;
