library IEEE;
use IEEE.std_logic_1164.all;

library UNISIM;
use UNISIM.Vcomponents.all;

entity top_hsstp_1lane_6250mbps is
	port (
		oLEDs:                out std_logic_vector(7 downto 0);
		iDIPs:                in  std_logic_vector(7 downto 0);
		iClk125P:             in  std_logic;
		iClk125N:             in  std_logic;
		iClk74_25P:           in  std_logic;
		iClk74_25N:           in  std_logic;
		iAuroraHpc1RefFixedN: in  std_logic;
		iAuroraHpc1RefFixedP: in  std_logic;
		oAuroraHpc1TxN:       out std_logic_vector(0 to 0);
		oAuroraHpc1TxP:       out std_logic_vector(0 to 0)
	);
end entity;

architecture behavioral of top_hsstp_1lane_6250mbps is
	constant cBytes:      positive := 4;

	signal wTraceClkSdr:  std_logic;
	signal wTraceDataSdr: std_logic_vector(31 downto 0);

	signal wClk125:       std_logic;
	signal wClk74_25:     std_logic;
	signal wClkUser:      std_logic;

	signal wTraceRst:     std_logic;
	signal wUserRst:      std_logic;
	signal wTraceRstN:    std_logic;
	signal wUserRstN:     std_logic;

	signal wFifoReady:    std_logic;
	signal wFifoData:     std_logic_vector(8 * cBytes - 1 downto 0);
	signal wFifoValid:    std_logic;
	signal wFifoLast:     std_logic;
	signal wFifoKeep:     std_logic_vector(cBytes - 1 downto 0);

begin
	-- main block design containing the Zynq UltraScale+ MPSoC
	yDesign: entity work.mpsoc port map (
		TRACE_CLK_SDR   => wTraceClkSdr,
		TRACE_DATA      => wTraceDataSdr
	);

	yAdapter: entity work.serial_trace_adapter_axis generic map (
		gBytes => cBytes
	) port map (
		iClk            => wTraceClkSdr,
		iRst            => wTraceRst,
		iData           => wTraceDataSdr,
		oData           => wFifoData,
		oValid          => wFifoValid,
		oLast           => wFifoLast,
		oKeep           => wFifoKeep
	);

	yAurora: entity work.aurora_1Lane port map (
		loopback        => "000",
		power_down      => '0',
		gt_refclk1_n    => iAuroraHpc1RefFixedN,
		gt_refclk1_p    => iAuroraHpc1RefFixedP,
		txn             => oAuroraHpc1TxN,
		txp             => oAuroraHpc1TxP,
		m_axis_aresetn  => wUserRstN,
		s_axis_aresetn  => wTraceRstN,
		s_axis_aclk     => wTraceClkSdr,
		s_axis_tready   => wFifoReady,
		s_axis_tdata    => wFifoData,
		s_axis_tvalid   => wFifoValid,
		s_axis_tlast    => wFifoLast,
		s_axis_tkeep    => (others => '1'),
		gt_reset        => wUserRst,
		init_clk_in     => wClk74_25,
		tx_system_reset => wUserRst,
		user_clk_out    => wClkUser
	);

	yBuf125: IBUFGDS port map (
		O               => wClk125,
		I               => iClk125P,
		IB              => iClk125N
	);

	yBuf74_25:        IBUFGDS port map (
		O               => wClk74_25,
		I               => iClk74_25P,
		IB              => iClk74_25N
	);

	-- this module is only used for debugging purposes to verify that all clocks are running and to see whether trace data is currently being transmitted
	yLedCommon: entity work.led_common generic map (
		gTraceSdrFreq   => 150.00e6,
		gUserFreq       => 156.25e6
	) port map (
		iClk125         => wClk125,
		iClk74_25       => wClk74_25,
		iClkTraceSdr    => wTraceClkSdr,
		iClkUser        => wClkUser,
		iTraceDataSdr   => wTraceDataSdr,
		iFifoReady      => wFifoReady,
		iFifoValid      => wFifoValid,
		oBlink125       => oLEDs(0),
		oBlink74_25     => oLEDs(1),
		oBlinkTraceSdr  => oLEDs(2),
		oBlinkUser      => oLEDs(3),
		oTraceActive    => oLEDs(4),
		oFifoOverflow   => oLEDs(5)
	);

	oLEDs(6) <= iDIPs(6);
	oLEDs(7) <= iDIPs(7);

	wTraceRst  <=     iDIPs(6);
	wTraceRstN <= not iDIPs(6);
	wUserRst   <=     iDIPs(7);
	wUserRstN  <= not iDIPs(7);
end architecture;
