library IEEE;
use IEEE.std_logic_1164.all;

library UNISIM;
use UNISIM.Vcomponents.all;

entity top_parallel_16bit is
	port (
		oLEDs:      out std_logic_vector(7 downto 0);
		iDIPs:      in  std_logic_vector(7 downto 0);
		iClk125P:   in  std_logic;
		iClk125N:   in  std_logic;
		iClk74_25P:  in  std_logic;
		iClk74_25N:  in  std_logic;
		oTraceClk:  out std_logic;
		oTraceData: out std_logic_vector(15 downto 0)
	);
end entity;

architecture behavioral of top_parallel_16bit is
	signal wTraceClkSdr:  std_logic;
	signal wTraceDataSdr: std_logic_vector(31 downto 0);

	signal wClk125:   std_logic;
	signal wClk74_25: std_logic;

begin
	-- main block design containing the Zynq UltraScale+ MPSoC
	yDesign: entity work.mpsoc port map (
		TRACE_CLK_SDR => wTraceClkSdr,
		TRACE_DATA    => wTraceDataSdr
	);

	-- trace adapter that instantiates DDR registers and manages traning sequences
	yParallelTraceAdapter: entity work.parallel_trace_adapter generic map (
		gPlatform      => "ULTRASCALE",
		gBitsIn        => 32,
		gBitsOut       => 16
	) port map (
		iClk           => wTraceClkSdr,
		iData          => wTraceDataSdr,
		oClk           => oTraceClk,
		oData          => oTraceData
	);

	-- these clocks are not needed by the design, but used to blink some LEDs
	yBuf125: IBUFGDS port map (
		O              => wClk125,
		I              => iClk125P,
		IB             => iClk125N
	);

	yBuf74_25:        IBUFGDS port map (
		O              => wClk74_25,
		I              => iClk74_25P,
		IB             => iClk74_25N
	);

	-- this module is only used for debugging purposes to verify that all clocks are running and to see whether trace data is currently being transmitted
	yLedCommon: entity work.led_common generic map (
		gTraceSdrFreq => 250.0e6
	) port map (
		iClk125        => wClk125,
		iClk74_25      => wClk74_25,
		iClkTraceSdr   => wTraceClkSdr,
		iTraceDataSdr  => wTraceDataSdr,
		oBlink125      => oLEDs(0),
		oBlink74_25    => oLEDs(1),
		oBlinkTraceSdr => oLEDs(2),
		oTraceActive   => oLEDs(4)
	);

	oLEDs(3) <= iDIPs(3);
	oLEDs(5) <= iDIPs(5);
	oLEDs(6) <= iDIPs(6);
	oLEDs(7) <= iDIPs(7);
end architecture;
